@@ -18,7 +18,7 @@ impl RadixKey for u16 {
 
     #[inline]
     fn get_level(&self, level: usize) -> u8 {
-        ((self >> ((Self::LEVELS - 1 - level) * 8)) as u8) & 0xff
+        (self >> ((Self::LEVELS - 1 - level) * 8)) as u8
     }
 }
 
@@ -27,7 +27,7 @@ impl RadixKey for u32 {
 
     #[inline]
     fn get_level(&self, level: usize) -> u8 {
-        ((self >> ((Self::LEVELS - 1 - level) * 8)) as u8) & 0xff
+        (self >> ((Self::LEVELS - 1 - level) * 8)) as u8
     }
 }
 
@@ -36,7 +36,7 @@ impl RadixKey for u64 {
 
     #[inline]
     fn get_level(&self, level: usize) -> u8 {
-        ((self >> ((Self::LEVELS - 1 - level) * 8)) as u8) & 0xff
+        (self >> ((Self::LEVELS - 1 - level) * 8)) as u8
     }
 }
 
@@ -45,7 +45,37 @@ impl RadixKey for u128 {
 
     #[inline]
     fn get_level(&self, level: usize) -> u8 {
-        ((self >> ((Self::LEVELS - 1 - level) * 8)) as u8) & 0xff
+        (self >> ((Self::LEVELS - 1 - level) * 8)) as u8
+    }
+}
+
+#[cfg(target_pointer_width = "16")]
+impl RadixKey for usize {
+    const LEVELS: usize = 2;
+
+    #[inline]
+    fn get_level(&self, level: usize) -> u8 {
+        (self >> ((Self::LEVELS - 1 - level) * 8)) as u8
+    }
+}
+
+#[cfg(target_pointer_width = "32")]
+impl RadixKey for usize {
+    const LEVELS: usize = 4;
+
+    #[inline]
+    fn get_level(&self, level: usize) -> u8 {
+        (self >> ((Self::LEVELS - 1 - level) * 8)) as u8
+    }
+}
+
+#[cfg(target_pointer_width = "64")]
+impl RadixKey for usize {
+    const LEVELS: usize = 8;
+
+    #[inline]
+    fn get_level(&self, level: usize) -> u8 {
+        (self >> ((Self::LEVELS - 1 - level) * 8)) as u8
     }
 }
 
